![](docsrc/_static/logo.png)

A Python package and command line utility for annotating the local ancestral sequence context of biallelic SNPs

![build and test](https://github.com/harrispopgen/mutyper/workflows/build%20and%20test/badge.svg)
![Python package](https://github.com/harrispopgen/mutyper/workflows/Python%20package/badge.svg)

#### See [documentation](https://harrispopgen.github.io/mutyper) for install and usage information.

Pairs well with the package [`mushi`](https://github.com/harrispopgen/mushi), which performs mutation spectrum history inference.
